CHANGE LOG
==========

0.1.4 - 2018.05.08
------------------
* [BUG FIX] Looked like an error was occuring because returning True
  instead of os.EX_OK.

0.1.3 - 2018.05.07
------------------
* [ENHANCEMENT] Added POSIX-style filename pattern matching for
  cleaning up tags.

0.1.2 - 2018.05.07
------------------
* Initial release!
